@@ -1,18 +1,23 @@
-from pydantic import BaseModel
+from dataclasses import dataclass
+from typing import Awaitable, Callable, Optional, Union
 import inspect
 import ast
 import os
 from . import globals
 
-class Config(BaseModel):
+@dataclass
+class Config():
     # NOTE: should be in sync with ui.run arguments
     host: str = '0.0.0.0'
     port: int = 8080
     title: str = 'NiceGUI'
     favicon: str = 'favicon.ico'
+    dark: Optional[bool] = False
     reload: bool = True
     show: bool = True
-    uvicorn_logging_level = 'warning'
+    on_connect: Optional[Union[Callable, Awaitable]] = None
+    uvicorn_logging_level: str = 'warning'
+    main_page_classes: str = 'q-ma-md column items-start'
     interactive: bool = False
 
 
@@ -34,7 +39,7 @@ try:
     with open(filepath) as f:
         source = f.read()
 except FileNotFoundError:
-    print('Could not find main script. Starting with interactive mode.', flush=True)
+    print('Could not find main script. Starting interactive mode without auto-reload.', flush=True)
     config = Config(interactive=True)
 else:
     for node in ast.walk(ast.parse(source)):
@@ -53,7 +58,8 @@ else:
         except AttributeError:
             continue
     else:
-        raise Exception('Could not find ui.run() command')
+        print('Could not find and pre-evaluate ui.run(). Starting interactive mode without auto-reload.', flush=True)
+        config = Config(interactive=True)
 
 os.environ['HOST'] = config.host
 os.environ['PORT'] = str(config.port)
