@@ -8,11 +8,11 @@ class Card(Group):
 
         Provides a container with a dropped shadow.
         """
-        view = jp.QCard(classes='column items-start q-pa-md', style='gap: 1em', delete_flag=False)
+        view = jp.QCard(classes='column items-start q-pa-md', style='gap: 1em', delete_flag=False, temp=False)
         super().__init__(view)
 
 class CardSection(Group):
 
     def __init__(self):
-        view = jp.QCardSection(delete_flag=False)
+        view = jp.QCardSection(delete_flag=False, temp=False)
         super().__init__(view)
