@@ -13,9 +13,9 @@ class Checkbox(BoolElement):
         """Checkbox Element
 
         :param text: the label to display next to the checkbox
-        :param value: set to `True` if it should be checked initally; default is `False`
+        :param value: whether it should be checked initally (default: `False`)
         :param on_change: callback to execute when value changes
         """
-        view = jp.QCheckbox(text=text, input=self.handle_change)
+        view = jp.QCheckbox(text=text, input=self.handle_change, temp=False)
 
         super().__init__(view, value=value, on_change=on_change)
