@@ -1,17 +1,17 @@
 import justpy as jp
-from typing import Any, Awaitable, Callable, Optional, Union
+from typing import Any, Awaitable, Callable, Dict, List, Optional, Union
 from .value_element import ValueElement
 
 class ChoiceElement(ValueElement):
 
     def __init__(self,
                  view: jp.HTMLBaseComponent,
-                 options: Union[list, dict],
+                 options: Union[List, Dict],
                  *,
                  value: Any,
                  on_change: Optional[Union[Callable, Awaitable]] = None,
                  ):
-        if isinstance(options, list):
+        if isinstance(options, List):
             view.options = [{'label': option, 'value': option} for option in options]
         else:
             view.options = [{'label': value, 'value': key} for key, value in options.items()]
