@@ -11,12 +11,13 @@ class Dialog(Group):
 
         Creates a modal dialog.
 
-        :param value: whether the dialog is already opened (default: False)
+        :param value: whether the dialog is already opened (default: `False`)
         """
         view = jp.QDialog(
             value=value,
             classes='row items-start bg-red-400',
             style='gap: 1em',
+            temp=False,
         )
 
         super().__init__(view)
