@@ -13,9 +13,9 @@ class Image(Group):
 
         Displays an image.
 
-        :param source: the source of the image; can be an url or a base64 string
+        :param source: the source of the image; can be an URL or a base64 string
         """
-        view = jp.QImg(src=source)
+        view = jp.QImg(src=source, temp=False)
         super().__init__(view)
 
         self.source = source
