@@ -11,9 +11,9 @@ class Menu(Group):
 
         Creates a menu.
 
-        :param value: whether the menu is already opened (default: False)
+        :param value: whether the menu is already opened (default: `False`)
         """
-        view = jp.QMenu(value=value)
+        view = jp.QMenu(value=value, temp=False)
 
         super().__init__(view)
 
