@@ -13,13 +13,13 @@ class Plot(Element):
 
         Create a context to configure a `Matplotlib <https://matplotlib.org/>`_ plot.
 
-        :param close: whether the figure should be closed after exiting the context; set to `False` if you want to update it later, default is `True`
+        :param close: whether the figure should be closed after exiting the context; set to `False` if you want to update it later (default: `True`)
         :param kwargs: arguments like `figsize` which should be passed to `pyplot.figure <https://matplotlib.org/stable/api/_as_gen/matplotlib.pyplot.figure.html>`_
         """
         self.close = close
         self.fig = plt.figure(**kwargs)
 
-        view = jp.Matplotlib()
+        view = jp.Matplotlib(temp=False)
         view.set_figure(self.fig)
 
         super().__init__(view)
