@@ -13,7 +13,7 @@ class Svg(Element):
 
         :param content: the svg definition
         """
-        view = jp.Div(style="padding:0;width:100%;height:100%")
+        view = jp.Div(style='padding:0;width:100%;height:100%', temp=False)
         super().__init__(view)
         self.content = content
 
