@@ -16,6 +16,6 @@ class Toggle(ChoiceElement):
         :param value: the inital value
         :param on_change: callback to execute when selection changes
         """
-        view = jp.QBtnToggle(input=self.handle_change)
+        view = jp.QBtnToggle(input=self.handle_change, temp=False)
 
         super().__init__(view, options, value=value, on_change=on_change)
