@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
 from typing import Awaitable, Callable
-import asyncio
 
 from .ui import Ui  # NOTE: before justpy
 import justpy as jp
@@ -33,6 +32,6 @@ def safe_invoke(func: Callable):
 app = globals.app = jp.app
 ui = Ui()
 
-page = ui.page('/')
+page = ui.page('/', classes=globals.config.main_page_classes)
 page.__enter__()
 jp.justpy(lambda: page, start_server=False)
