@@ -1,3 +1,4 @@
+from typing import Awaitable, Callable, Optional, Union
 import inspect
 import sys
 import webbrowser
@@ -17,9 +18,12 @@ def run(self, *,
         port: int = 8080,
         title: str = 'NiceGUI',
         favicon: str = 'favicon.ico',
+        dark: Optional[bool] = False,
         reload: bool = True,
         show: bool = True,
+        on_connect: Optional[Union[Callable, Awaitable]] = None,
         uvicorn_logging_level: str = 'warning',
+        main_page_classes: str = 'q-ma-md column items-start',
         ):
 
     if globals.config.interactive or reload == False:  # NOTE: if reload == True we already started uvicorn above
