@@ -3,12 +3,15 @@ class Ui:
     from .run import run  # NOTE: before justpy
 
     from .elements.button import Button as button
+    from .elements.chart import Chart as chart
     from .elements.checkbox import Checkbox as checkbox
+    from .elements.colors import Colors as colors
     from .elements.custom_example import CustomExample as custom_example
     from .elements.dialog import Dialog as dialog
     from .elements.icon import Icon as icon
     from .elements.image import Image as image
     from .elements.input import Input as input
+    from .elements.interactive_image import InteractiveImage as interactive_image
     from .elements.joystick import Joystick as joystick
     from .elements.html import Html as html
     from .elements.label import Label as label
